@@ -2,12 +2,14 @@ from .preprocessing import create_dataloader
 import torch
 import numpy as np
 from tqdm import tqdm 
+from nltk.tokenize import sent_tokenize, word_tokenize
 
 # NOTE: genbrug kode fra evaluering af model på validering?
 # TODO: add batch_size, num_workers (til dataloader) som args.
 def predict(network = None, 
             sentences = None,
             transformer_tokenizer = None,
+            transformer_config = None,
             max_len = 128,
             device = None,
             tag_encoder = None):
@@ -24,6 +26,7 @@ def predict(network = None,
     dl = create_dataloader(sentences,
                            tags_dummy, 
                            transformer_tokenizer,
+                           transformer_config,
                            max_len = max_len, 
                            batch_size = 1, 
                            tag_encoder = tag_encoder)
@@ -52,4 +55,29 @@ def predict(network = None,
 
     return predictions
 
+def predict_text(network = None, 
+                 text = "Ronaldo spiller i Juventus. Han er god.",
+                 transformer_tokenizer = None,
+                 transformer_config = None,
+                 max_len = 128,
+                 device = None,
+                 tag_encoder = None,
+                 sent_tokenizer = sent_tokenize,
+                 word_tokenizer = word_tokenize):
+
+    sentences = sent_tokenize(text)
+
+    sentences = [word_tokenize(sentence) for sentence in sentences]
+
+    predictions = predict(network = network, 
+                          sentences = sentences,
+                          transformer_tokenizer = transformer_tokenizer,
+                          transformer_config = transformer_config,
+                          max_len = max_len,
+                          device = device,
+                          tag_encoder = tag_encoder)
+
+    return sentences, predictions
+
+
 
